@@ -178,16 +178,12 @@ sub repair {
   my $minion = $self->minion;
   $db->query("DELETE FROM minion_workers WHERE notified < NOW() - INTERVAL '1 second' * ?", $minion->missing_after);
 
-  # Old jobs with no unresolved dependencies and expired jobs
-  $db->query(
-    "DELETE FROM minion_jobs WHERE id IN (
-       SELECT j.id FROM minion_jobs AS j LEFT JOIN minion_jobs AS children
-         ON children.state != 'finished' AND ARRAY_LENGTH(children.parents, 1) > 0 AND j.id = ANY(children.parents)
-       WHERE j.state = 'finished' AND j.finished <= NOW() - INTERVAL '1 second' * ? AND children.id IS NULL
-       UNION ALL
-       SELECT id FROM minion_jobs WHERE state = 'inactive' AND expires <= NOW()
-    )", $minion->remove_after
-  );
+  # Old jobs
+  $db->query("DELETE FROM minion_jobs WHERE state = 'finished' AND finished <= NOW() - INTERVAL '1 second' * ?",
+    $minion->remove_after);
+
+  # Expired jobs
+  $db->query("DELETE FROM minion_jobs WHERE state = 'inactive' AND expires <= NOW()");
 
   # Jobs with missing worker (can be retried)
   $db->query(
